==> dclib-0.3.17.tar.bz2: dclib-0.3.17/dclib/core/czlib.h <==
/***************************************************************************
                           czlib.h  -  description
                             -------------------
    begin                : Thu Oct 12 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CZLIB_H
#define CZLIB_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/cobject.h>
#include <dclib/core/cbytearray.h>

#include <zlib.h>

class DLL_EXPORT CZLib : public CObject {

public:
	/** */
	CZLib();
	/** */
	virtual ~CZLib();

	/**
	 * inflate block
	 * -1 error
	 *  0 finished (stream end)
	 *  1 more data to process
	 */
	int InflateZBlock( char * in, int * inlen, char * out, int * outlen );
	/** */
	unsigned long GetTotalOut() const { return m_ZStream.total_out; };
	/** Returns size of decompressed output , or zero on error */
	unsigned long OneShotInflate( const char * in, const unsigned long inlen, CByteArray * out );

private:
	/** */
	bool m_bInit;
	/** */
	struct z_stream_s m_ZStream;
};

class DLL_EXPORT CDeflater: public CObject {

public:
	/** Constructor */
	CDeflater();
	/** Destructor */
	virtual ~CDeflater();
	
	/**
	 * deflate block
	 * -1 error
	 *  0 finished (stream end)
	 *  1 more data to process
	 */
	int DeflateBlock( char * in, int * inlen, char * out, int * outlen, bool more );
	/** */
	unsigned long GetTotalOut() const { return m_ZStream.total_out; };
	/** Returns size of compressed output, or zero on error */
	unsigned long OneShotDeflate( const char * in, const unsigned long inlen, CByteArray * out );

private:
	/** */
	bool m_bInit;
	/** */
	struct z_stream_s m_ZStream;
};

#endif

==> dclib-0.3.21.tar.bz2: dclib-0.3.21/dclib/core/czlib.h <==
/***************************************************************************
                           czlib.h  -  description
                             -------------------
    begin                : Thu Oct 12 2004
    copyright            : (C) 2004 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CZLIB_H
#define CZLIB_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>

class CByteArray;

struct z_stream_s;

class DLL_EXPORT CZLib {

public:
	/** */
	CZLib();
	/** */
	~CZLib();

	/**
	 * inflate block
	 * -1 error
	 *  0 finished (stream end)
	 *  1 more data to process
	 */
	int InflateZBlock( const char * in, int * inlen, char * out, int * outlen );
	/** */
	unsigned long GetTotalOut() const;
	/** Returns size of decompressed output , or zero on error */
	static unsigned long OneShotInflate( const char * in, const unsigned long inlen, CByteArray * out );

private:
	/** */
	bool m_bInit;
	/** */
	struct z_stream_s * m_pZStream;
};

class DLL_EXPORT CDeflater {

public:
	/** Constructor */
	CDeflater();
	/** Destructor */
	~CDeflater();
	
	/**
	 * deflate block
	 * -1 error
	 *  0 finished (stream end)
	 *  1 more data to process
	 */
	int DeflateBlock( const char * in, int * inlen, char * out, int * outlen, bool more );
	/** */
	unsigned long GetTotalOut() const;
	/** Returns size of compressed output, or zero on error */
	static unsigned long OneShotDeflate( const char * in, const unsigned long inlen, CByteArray * out );

private:
	/** */
	bool m_bInit;
	/** */
	struct z_stream_s * m_pZStream;
};

#endif
